package
Version:
v0.4.0
Opens a new window with list of versions in this module.
Published: Jul 15, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package models contains application-owned entities and transport DTOs.
type HealthResponse struct {
Status string `json:"status"`
App string `json:"app"`
}
type HelloInput struct {
Name string `json:"name" query:"name" validate:"omitempty,max=60"`
}
type HelloMessage struct {
gorm.Model
Slug string `gorm:"size:64;not null;uniqueIndex:ux_hello_slug_lang,priority:1"`
Lang string `gorm:"size:16;not null;uniqueIndex:ux_hello_slug_lang,priority:2;index"`
Message string `gorm:"size:255;not null"`
}
type HelloResponse struct {
App string `json:"app"`
Message string `json:"message"`
Locale string `json:"locale"`
Authenticated bool `json:"authenticated"`
IdentityID string `json:"identity_id,omitempty"`
Role string `json:"role,omitempty"`
Source string `json:"source"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.